@@ -35,6 +35,7 @@ from tracers.daemon import (
     send_result_to_daemon,
 )
 from tracers.utils import (
+    condition,
     delta,
     divide,
     get_function_id,
@@ -47,7 +48,7 @@ FunctionWrapper = Callable[[Callable[..., Any]], Callable[..., Any]]
 
 def measure_loop_skew(
     clock_id: int,
-    should_measure_loop_skew: threading.Event,
+    should_measure: threading.Event,
     snapshots: List[LoopSnapshot],
 ) -> None:
 
@@ -72,7 +73,7 @@ def measure_loop_skew(
         schedule_callback(wanted_tick_duration)
 
     def schedule_callback(wanted_tick_duration: float) -> None:
-        if should_measure_loop_skew.is_set():
+        if should_measure.is_set():
             with contextlib.suppress(RuntimeError):
                 callback_handler_args: Tuple[float, float] = (
                     wanted_tick_duration, time.clock_gettime(clock_id),
@@ -115,9 +116,8 @@ def _get_wrapper(  # noqa: MC001
             @functools.wraps(function)
             async def isolated_wrapper(*args: Any, **kwargs: Any) -> Any:
                 if do_trace and TRACING.get():
-                    should_measure_loop_skew = threading.Event()
-
-                    with increase_counter(LEVEL):
+                    with condition() as should_measure_loop_skew, \
+                            increase_counter(LEVEL):
                         if LEVEL.get() == 1:
                             should_measure_loop_skew.set()
                             snapshots: List[LoopSnapshot] = []
@@ -140,7 +140,6 @@ def _get_wrapper(  # noqa: MC001
                                     stack=stack,
                                 ),
                             )
-                            should_measure_loop_skew.clear()
                 else:
                     # Disable downstream tracers
                     TRACING.set(False)
