@@ -6,6 +6,7 @@ from contextvars import (
     Token,
 )
 import sys
+import threading
 from typing import (
     Any,
     Callable,
@@ -13,6 +14,15 @@ from typing import (
 )
 
 
+@contextlib.contextmanager
+def condition() -> Iterator[threading.Event]:
+    instance: threading.Event = threading.Event()
+    try:
+        yield instance
+    finally:
+        instance.clear()
+
+
 def delta(start_timestamp: float, end_timestamp: float) -> float:
     return end_timestamp - start_timestamp
 
